searchData={"items":[{"type":"module","title":"LibLatLon","doc":"This module is basically the only module consumers of this library\n  should be interested in.\n\nThere is a single function exported: [`LibLatLon.lookup/3`].","ref":"LibLatLon.html"},{"type":"function","title":"LibLatLon.lookup/3","doc":"Pass anything to lookup using default provider and with default options.\nPass a provider as the second argument to use a specific provider.\nPass options map like `%{language: \"es\"}` as a last parameter to\n  tune the provider’s response. _NB:_ options are provider-specific.","ref":"LibLatLon.html#lookup/3"},{"type":"function","title":"Examples - LibLatLon.lookup/3","doc":"iex> LibLatLon.lookup(\n    ...>   {42, 3.14159265},\n    ...>   LibLatLon.Providers.Dummy,\n    ...>   %{extended: true}).details\n    %{\n      city: \"Barcelona\",\n      city_district: \"Sant Martí\",\n      country: \"España\",\n      country_code: \"es\",\n      county: \"BCN\",\n      postcode: \"08020\",\n      road: \"Avinguda del Litoral\",\n      state: \"CAT\",\n      suburb: \"la Vila Olímpica del Poblenou\"\n    }","ref":"LibLatLon.html#lookup/3-examples"},{"type":"behaviour","title":"LibLatLon.Provider","doc":"The default behaviour for all the geo providers.\n\nImplementations known:\n\n* `LibLatLon.Providers.OpenStreetMap`\n* `LibLatLon.Providers.GoogleMaps`\n\nContributions are _very welcome_.","ref":"LibLatLon.Provider.html"},{"type":"callback","title":"LibLatLon.Provider.lookup/2","doc":"Performs either a normal lookup by any string or\n  a reverse lookup by latitude and longitude","ref":"LibLatLon.Provider.html#c:lookup/2"},{"type":"callback","title":"LibLatLon.Provider.name/0","doc":"Returns a name of this provider to display","ref":"LibLatLon.Provider.html#c:name/0"},{"type":"module","title":"LibLatLon.Bounds","doc":"Convenient storage for geo bounds.","ref":"LibLatLon.Bounds.html"},{"type":"type","title":"LibLatLon.Bounds.t/0","doc":"The `Bouds` struct has two fields (`from` and `to`).\n\n* `from` denoting the _northeast_ boundary, and\n* `to` denoting the _southwest_ boundary.\n\n# Example\n\n_GoogleMaps API_ returns the same structure from geocoding requests:\n\n    %{...\n      \"geometry\" => %{\n        \"bounds\" => %{\n          \"northeast\" => %{\"lat\" => 41.3884209, \"lng\" => 2.1982486},\n          \"southwest\" => %{\"lat\" => 41.3874997, \"lng\" => 2.1970767}\n        }\n        ...","ref":"LibLatLon.Bounds.html#t:t/0"},{"type":"module","title":"LibLatLon.Coords","doc":"Main struct to be used as coordinates representation.\n\nOne might cast nearly everything to `LibLatLon.Coord` with\n`LibLatLon.Coord.borrow/1` and/or `LibLatLon.Coord.borrow/2`.\n\nThis struct implements both `String.Chars` and `Inspect` protocols.\nThe fancy string representation of any lat/lon pair might be get by\n`Kernel.to_string/1`:\n\n    iex> to_string(LibLatLon.Coords.borrow(lat: 41.38, lon: 2.19))\n    \"41°22´48.0˝N,2°11´24.0˝E\"\n\nNote, that this representation might be used as is when querying any\ngeolocation services and/or `GoogleMaps`. Try:\n\n* http://maps.google.com?search=41°22´48.0˝N,2°11´24.0˝E","ref":"LibLatLon.Coords.html"},{"type":"function","title":"LibLatLon.Coords.borrow/1","doc":"Converts literally any input to `LibLatLon.Coords` instance.","ref":"LibLatLon.Coords.html#borrow/1"},{"type":"function","title":"Examples - LibLatLon.Coords.borrow/1","doc":"iex> LibLatLon.Coords.borrow(\"41°23´16˝N,2°11´50˝E\")\n    %LibLatLon.Coords{lat: 41.38777777777778, lon: 2.197222222222222}\n\n    iex> LibLatLon.Coords.borrow(\"41°23´16.222˝N,2°11´50.333˝E\")\n    %LibLatLon.Coords{lat: 41.387839444444445, lon: 2.197314722222222}\n\n    iex> LibLatLon.Coords.borrow({{{41, 23, 16.0}, \"N\"}, {{2, 11, 50.0}, \"E\"}})\n    %LibLatLon.Coords{lat: 41.38777777777778, lon: 2.197222222222222}\n\n    iex> LibLatLon.Coords.borrow(lat: 41.38, lon: 2.19)\n    %LibLatLon.Coords{lat: 41.38, lon: 2.19}","ref":"LibLatLon.Coords.html#borrow/1-examples"},{"type":"function","title":"LibLatLon.Coords.borrow/2","doc":"Converts `{{degree, minute, second}, semisphere}` or\n  `{[degree, minute, second], semisphere}` representation into\n  `LibLatLon.Coords`.","ref":"LibLatLon.Coords.html#borrow/2"},{"type":"function","title":"LibLatLon.Coords.borrow/4","doc":"Converts `degree, minute, second, semisphere` representation into\n  `LibLatLon.Coords`. When the last parameter `semisphere` is not one of:\n  `\"S\"` or `\"W\"` or `-1` or `:south` or `west`, it is implicitly\n  considered to be in `NE` semisphere.","ref":"LibLatLon.Coords.html#borrow/4"},{"type":"function","title":"LibLatLon.Coords.coordinate/1","doc":"Retrieves coordinates from barely anything.\n\n    iex> {:ok, result} = LibLatLon.Coords.coordinate(\"test/inputs/1.jpg\")\n    ...> result\n    #Coord<[lat: 41.37600333333334, lon: 2.1486783333333332, fancy: \"41°22´33.612˝N,2°8´55.242˝E\"]>\n\n    iex> LibLatLon.Coords.coordinate(\"test/inputs/unknown.jpg\")\n    {:error, {:weird_input, [nil]}}","ref":"LibLatLon.Coords.html#coordinate/1"},{"type":"function","title":"LibLatLon.Coords.coordinate!/1","doc":"Same as `LibLatLon.Coords.coordinate/1`, but banged.","ref":"LibLatLon.Coords.html#coordinate!/1"},{"type":"function","title":"Examples - LibLatLon.Coords.coordinate!/1","doc":"iex> LibLatLon.Coords.coordinate!(\"test/inputs/1.jpg\")\n    #Coord<[lat: 41.37600333333334, lon: 2.1486783333333332, fancy: \"41°22´33.612˝N,2°8´55.242˝E\"]>","ref":"LibLatLon.Coords.html#coordinate!/1-examples"},{"type":"function","title":"LibLatLon.Coords.lend/1","doc":"Converts literally anything, provided as combined `latlon` value\n  to two tuples `{{degree, minute, second}, semisphere}`. Barely used\n  from the outside the package, since `LibLatLon.Coords.t` is obviously\n  better type to work with coordinates by all means.","ref":"LibLatLon.Coords.html#lend/1"},{"type":"function","title":"Examples - LibLatLon.Coords.lend/1","doc":"iex> LibLatLon.Coords.lend({41.38777777777778, 2.197222222222222})\n    {{{41, 23, 16.0}, \"N\"}, {{2, 11, 50.0}, \"E\"}}\n\n    iex> LibLatLon.Coords.lend([41.38777777777778, 2.197222222222222])\n    {{{41, 23, 16.0}, \"N\"}, {{2, 11, 50.0}, \"E\"}}","ref":"LibLatLon.Coords.html#lend/1-examples"},{"type":"function","title":"LibLatLon.Coords.lend/2","doc":"Converts literally anything, provided as latitude _and_ longitude values\n  to two tuples `{{degree, minute, second}, semisphere}`. Barely used\n  from the outside the package, since `LibLatLon.Coords.t` is obviously\n  better type to work with coordinates by all means.","ref":"LibLatLon.Coords.html#lend/2"},{"type":"function","title":"Examples - LibLatLon.Coords.lend/2","doc":"iex> LibLatLon.Coords.lend(41.38777777777778, 2.197222222222222)\n    {{{41, 23, 16.0}, \"N\"}, {{2, 11, 50.0}, \"E\"}}","ref":"LibLatLon.Coords.html#lend/2-examples"},{"type":"type","title":"LibLatLon.Coords.dms/0","doc":"Degrees, minutes and seconds as a tuple","ref":"LibLatLon.Coords.html#t:dms/0"},{"type":"type","title":"LibLatLon.Coords.dms_list/0","doc":"Degrees, minutes and seconds as a list","ref":"LibLatLon.Coords.html#t:dms_list/0"},{"type":"type","title":"LibLatLon.Coords.dms_ss/0","doc":"Degrees, minutes and seconds with an optional semisphere reference","ref":"LibLatLon.Coords.html#t:dms_ss/0"},{"type":"type","title":"LibLatLon.Coords.t/0","doc":"The type to store coordinates.\n\nMostly used fields are `lat` and `lon`, stored as `Float.t`. Also\nmight contain `altitude` and `direction` to calculate the latitude\nand langitude for the destination point (mostly used when dealing with\n`EXIF` information from images.)","ref":"LibLatLon.Coords.html#t:t/0"},{"type":"module","title":"LibLatLon.Info","doc":"Main storage struct for holding information about any place/POI/address\nin the unified form.","ref":"LibLatLon.Info.html"},{"type":"module","title":"Example: - LibLatLon.Info","doc":"LibLatLon.lookup {41.38777777777778, 2.197222222222222}\n\n    %LibLatLon.Info{\n      address: \"Avinguda del Litoral, [...] España\",\n      bounds: %LibLatLon.Bounds{\n        from: #Coord<[\n          lat: 41.3876663,\n          lon: 2.196602,\n          fancy: \"41°23´15.59868˝N,2°11´47.7672˝E\"\n        ]>,\n        to: #Coord<[\n          lat: 41.3917431,\n          lon: 2.2031084,\n          fancy: \"41°23´30.27516˝N,2°12´11.19024˝E\"\n        ]>\n      },\n      coords: #Coord<[\n        lat: 41.3899932,\n        lon: 2.2000054,\n        fancy: \"41°23´23.97552˝N,2°12´0.01944˝E\"\n      ]>,\n      details: %{\n        city: \"Barcelona\",\n        city_district: \"Sant Martí\",\n        country: \"España\",\n        country_code: \"es\",\n        county: \"BCN\",\n        postcode: \"08020\",\n        road: \"Avinguda del Litoral\",\n        state: \"CAT\",\n        suburb: \"la Vila Olímpica del Poblenou\"\n      },\n      meta: %{\n        licence: \"Data © OpenStreetMap [...]\",\n        osm_id: \"47123759\",\n        osm_type: \"way\",\n        place_id: \"82181109\"\n      }\n    }","ref":"LibLatLon.Info.html#module-example"},{"type":"function","title":"LibLatLon.Info.format/2","doc":"Formats the `String.t` representation of this struct according to\n  the format given.\n\nSecond parameter `format` might include `%{field}` inclusions\nwhich will be interpolated in the result with real values.","ref":"LibLatLon.Info.html#format/2"},{"type":"function","title":"Examples - LibLatLon.Info.format/2","doc":"iex> info = LibLatLon.lookup({42, 3.14159265}, LibLatLon.Providers.Dummy)\n    iex> LibLatLon.Info.format(info, \"⚑ %{country}, %{city}, %{postcode}.\")\n    \"⚑ España, Barcelona, 08021.\"","ref":"LibLatLon.Info.html#format/2-examples"},{"type":"function","title":"LibLatLon.Info.from_map/1","doc":"Mostly internal helper. You would unlikely call this function yourself.\n\nGets the map as returned by geo location provider and contructs\n  fields in unified format.","ref":"LibLatLon.Info.html#from_map/1"},{"type":"function","title":"LibLatLon.Info.from_map!/1","doc":"The same as `LibLatLon.Info.from_map/1`, but banged.","ref":"LibLatLon.Info.html#from_map!/1"},{"type":"type","title":"LibLatLon.Info.t/0","doc":"Main type to store geo point in unified form.\n\n* `LibLatLon.Bounds.t` for `bounds` field\n* `LibLatLon.Coords.t` for `coords` key\n\n`address` is a string, representing the whole address in human-readable form.\n\n`details` and `meta` are _not_ unified maps of fields, as returned\n  by geo location provider. Their keys differ for different providers.","ref":"LibLatLon.Info.html#t:t/0"},{"type":"module","title":"LibLatLon.Providers.GoogleMaps","doc":"`GoogleMaps` provider implementation.","ref":"LibLatLon.Providers.GoogleMaps.html"},{"type":"function","title":"LibLatLon.Providers.GoogleMaps.lookup/2","doc":"Implements a lookup for `GoogleMaps` provider. Returns either\n  `{:ok, %LibLatLon.Info{}}` or `{:error, reason}` tuple.\n\nUsed internally by `LibLatLon.lookup/1`.","ref":"LibLatLon.Providers.GoogleMaps.html#lookup/2"},{"type":"module","title":"LibLatLon.Providers.OpenStreetMap","doc":"`OpenStreetMap` provider implementation.","ref":"LibLatLon.Providers.OpenStreetMap.html"},{"type":"function","title":"LibLatLon.Providers.OpenStreetMap.lookup/2","doc":"Implements a lookup for `OpenStreetMap` provider. Returns either\n  `{:ok, %LibLatLon.Info{}}` or `{:error, reason}` tuple.\n\nUsed internally by `LibLatLon.lookup/1`.","ref":"LibLatLon.Providers.OpenStreetMap.html#lookup/2"},{"type":"extras","title":"LibLatLon","doc":"# LibLatLon\n\n[![HexPM](https://img.shields.io/hexpm/v/lib_lat_lon.svg)](https://hex.pm/packages/lib_lat_lon) \n[![GHA](https://github.com/amotion-city/lib_lat_lon/workflows/Test/badge.svg)](https://github.com/amotion-city/lib_lat_lon/actions) \n[![Inline docs](http://inch-ci.org/github/amotion-city/lib_lat_lon.svg)](http://inch-ci.org/github/amotion-city/lib_lat_lon) \n[![License badge](https://img.shields.io/hexpm/l/lib_lat_lon.svg)](https://github.com/amotion-city/lib_lat_lon/blob/master/LICENSE.md) \n[![Read the Docs](/stuff/images/docs-passing.png?raw=true)](https://hexdocs.pm/lib_lat_lon) \n[![Code coverage badge](https://img.shields.io/codecov/c/github/amotion-city/lib_lat_lon/master.svg)](https://codecov.io/gh/amotion-city/lib_lat_lon)\n\n**{:ok, 📍}** handy library for managing geo coordinates that\nincludes _direct/reverse geocoding_ features.","ref":"intro.html"},{"type":"extras","title":"Installation - LibLatLon","doc":"```elixir\n# config/config.exs\n\n# Use PragDave’s exexif (default)\nconfig :lib_lat_lon, :exexif, :exexif\n\n# Use AM’s exexif\nconfig :lib_lat_lon, :exexif, :nextexif\n```\n\n```elixir\n# mix.exs\ndef deps do\n  [\n    {:lib_lat_lon, \"~> 0.7\"}\n  ]\nend\n```\n\n#","ref":"intro.html#installation"},{"type":"extras","title":"Usage - LibLatLon","doc":"##","ref":"intro.html#usage"},{"type":"extras","title":"Reverse lookup - LibLatLon","doc":"```elixir\nLibLatLon.lookup {41.38777777777778, 2.197222222222222}\n\n%LibLatLon.Info{\n  address: \"Avinguda del Litoral, [...] España\",\n  bounds: %LibLatLon.Bounds{\n    from: #Coord<[\n      lat: 41.3876663,\n      lon: 2.196602,\n      fancy: \"41°23´15.59868˝N,2°11´47.7672˝E\"\n    ]>,\n    to: #Coord<[\n      lat: 41.3917431,\n      lon: 2.2031084,\n      fancy: \"41°23´30.27516˝N,2°12´11.19024˝E\"\n    ]>\n  },\n  coords: #Coord<[\n    lat: 41.3899932,\n    lon: 2.2000054,\n    fancy: \"41°23´23.97552˝N,2°12´0.01944˝E\"\n  ]>,\n  details: %{\n    city: \"Barcelona\",\n    city_district: \"Sant Martí\",\n    country: \"España\",\n    country_code: \"es\",\n    county: \"BCN\",\n    postcode: \"08020\",\n    road: \"Avinguda del Litoral\",\n    state: \"CAT\",\n    suburb: \"la Vila Olímpica del Poblenou\"\n  },\n  meta: %{\n    licence: \"Data © OpenStreetMap [...]\",\n    osm_id: \"47123759\",\n    osm_type: \"way\",\n    place_id: \"82181109\"\n  }\n}\n```\n\n##","ref":"intro.html#reverse-lookup"},{"type":"extras","title":"Direct lookup, using `GoogleMaps` - LibLatLon","doc":"```elixir\nLibLatLon.lookup(\n  \"Av. del Litoral, 28, 08005 Barcelona, Spain\",\n  LibLatLon.Providers.GoogleMaps)\n\n%LibLatLon.Info{\n  address: \"Av. del Litoral, 28, 08005 Barcelona, Spain\",\n  bounds: %LibLatLon.Bounds{\n    from: #Coord<[\n      lat: 41.3893258802915,\n      lon: 2.198497180291502,\n      fancy: \"41°23´21.57316905˝N,2°11´54.58984905˝E\"\n    ]>,\n    to: #Coord<[\n      lat: 41.3866279197085,\n      lon: 2.195799219708499,\n      fancy: \"41°23´11.86051095˝N,2°11´44.87719095˝E\"\n    ]>\n  },\n  coords: #Coord<[\n    lat: 41.3879769,\n    lon: 2.1971482,\n    fancy: \"41°23´16.71684˝N,2°11´49.73352˝E\"\n  ]>,\n  details: %{\n    administrative_area_level_1: \"Catalunya\",\n    administrative_area_level_2: \"Barcelona\",\n    country: \"Spain\",\n    locality: \"Barcelona\",\n    postal_code: \"08005\",\n    route: \"Avinguda del Litoral\",\n    street_number: \"28\"\n  },\n  meta: %{place_id: \"ChIJB801WA6jpBIRLvQ6BHMtKB4\", types: [\"street_address\"]}\n}\n```\n\n#","ref":"intro.html#direct-lookup-using-googlemaps"},{"type":"extras","title":"Currently supported providers - LibLatLon","doc":"* [GoogleMaps](https://developers.google.com/maps/documentation/geocoding/intro#geocoding);\n* [OpenStreetMaps](https://nominatim.openstreetmap.org/).\n\n#","ref":"intro.html#currently-supported-providers"},{"type":"extras","title":"Currently supported sources - LibLatLon","doc":"* latitude/longitude pair in any form (e.g. `{lat, lon}` tuple);\n* an address as a `binary()`;\n* a `jpeg` image with `gps` information.\n\n##","ref":"intro.html#currently-supported-sources"},{"type":"extras","title":"Notes about `GoogleMaps` - LibLatLon","doc":"To use `LibLatLon.Providers.GoogleMaps` provider, go\n[get API key](https://developers.google.com/maps/documentation/geocoding/get-api-key)\nfrom Google and put the following lines into your `config.exs` file:\n\n```elixir\nconfig :lib_lat_lon, :provider, LibLatLon.Providers.GoogleMaps\nconfig :lib_lat_lon, :google_maps_api_key, \"YOUR_GOOGLE_API_KEY\"\n```\n\nor, alternatively, use the system environment variable `GOOGLE_MAPS_API_KEY`.\n\n#","ref":"intro.html#notes-about-googlemaps"},{"type":"extras","title":"Docs / Changelog - LibLatLon","doc":"Documentation can be found at [https://hexdocs.pm/lib_lat_lon](https://hexdocs.pm/lib_lat_lon).","ref":"intro.html#docs-changelog"}],"content_type":"text/markdown"}